==> hoolihan-1.0.9.tgz: package/README.md <==
# Hoolihan &middot; [![npm](https://img.shields.io/npm/v/hoolihan.svg)](https://www.npmjs.com/package/hoolihan) [![Build Status](https://img.shields.io/travis/bradcordeiro/hoolihan.svg)](https://travis-ci.org/bradcordeiro/hoolihan) [![Code Coverage](https://img.shields.io/coveralls/github/bradcordeiro/hoolihan.svg)](https://coveralls.io/github/bradcordeiro/hoolihan) [![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com) [![GitHub license](https://img.shields.io/npm/l/hoolihan.svg)](https://github.com/bradcordeiro/hoolihan/blob/master/LICENSE)

Hoolihan is a JavaScript module to help build Ffmpeg command-line options, and run Ffmpeg with those options as a NodeJS child process. You,   must "bring your own" build of ffmpeg and ffprobe, and Hoolihan does some work to read the capabilities of your particular build.

## Installing / Getting started

Hoolihan includes mocha, chai, and eslint as devDependencies. Use the optional `--production` flag when installing to omit them.

```shell
npm install hoolihan [--production]
```

See [Configuration](#configuration) for how to point Hoolihan at your builds of Ffmpeg and Ffprobe.

## Developing

### Setting up Dev

```shell
git clone https://github.com/bradcordeiro/hoolihan.git
cd hoolihan/
npm install
```

## Versioning

Hoolihan uses  [SemVer](http://semver.org/) for versioning.

## Configuration

Hoolihan uses [dotenv](https://github.com/motdotla/dotenv) to know where your Ffmpeg and Ffprobe binaries are, as well as the default font file to be used for Ffmpeg's `drawtext` filter. Create a file named `.env` in your project root with the following variables, set to your desired values:

```shell
# .env
FFMPEG_BIN=ffmpeg
FFPROBE_BIN=ffprobe
DRAWTEXTFONT=/Users/administrator/Library/Fonts/AverageMono.ttf
```

## Tests

Numerous tests are included, most of them written before this module got any real-world use. To run, install mocha and chai, then:

```shell
npm test
```

## Style guide

Uses the [Airbnb JavaScript Style Guide](https://github.com/airbnb/javascript). Eslint is listed as a devDependency, and a `.eslintrc.json` is checked into source control.

## API Reference

Please see [the wiki](https://github.com/bradcordeiro/hoolihan/wiki).


## Licensing

Released under a [Creative Commons Attribution-NonCommercial 4.0 International Public License](https://creativecommons.org/licenses/by-nc/4.0/).

==> hoolihan-1.0.17.tgz: package/README.md <==
# Hoolihan &middot; [![npm](https://img.shields.io/npm/v/hoolihan.svg)](https://www.npmjs.com/package/hoolihan) [![Build Status](https://img.shields.io/travis/bradcordeiro/hoolihan.svg)](https://travis-ci.org/bradcordeiro/hoolihan) [![Code Coverage](https://img.shields.io/coveralls/github/bradcordeiro/hoolihan.svg)](https://coveralls.io/github/bradcordeiro/hoolihan) [![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com) [![GitHub license](https://img.shields.io/npm/l/hoolihan.svg)](https://github.com/bradcordeiro/hoolihan/blob/master/LICENSE)

Hoolihan is a JavaScript module to help build Ffmpeg command-line options, and run Ffmpeg with those options as a NodeJS child process. You,   must "bring your own" build of ffmpeg and ffprobe, and Hoolihan does some work to read the capabilities of your particular build.

## Installing / Getting started

Hoolihan includes mocha, chai, and eslint as devDependencies. Use the optional `--production` flag when installing to omit them.

```shell
npm install hoolihan [--production]
```

See [Configuration](#configuration) for how to point Hoolihan at your builds of Ffmpeg and Ffprobe.

## Developing

### Setting up Dev

```shell
git clone https://github.com/bradcordeiro/hoolihan.git
cd hoolihan/
npm install
```

## Versioning

Hoolihan uses  [SemVer](http://semver.org/) for versioning.

## Configuration

Hoolihan uses [dotenv](https://github.com/motdotla/dotenv) to know where your Ffmpeg and Ffprobe binaries are, as well as the default font file to be used for Ffmpeg's `drawtext` filter. Create a file named `.env` in your project root with the following variables, set to your desired values. Spaces are allowed in binary locations, for instance if using a dockerized Ffmpeg binary:

```shell
# .env
FFMPEG_BIN=docker run --rm myimages/ffmpeg
FFPROBE_BIN=/usr/local/bin/ffprobe
DRAWTEXTFONT=/Users/administrator/Library/Fonts/AverageMono.ttf
```

## Tests

Numerous tests are included, most of them written before this module got any real-world use. Pull requests with new tests are welcome. To run, install mocha and chai, then:

```shell
npm test
```

## Style guide

Uses the [Airbnb JavaScript Style Guide](https://github.com/airbnb/javascript). Eslint is listed as a devDependency, and a `.eslintrc.json` is checked into source control.

## API Reference

Please see [the wiki](https://github.com/bradcordeiro/hoolihan/wiki).

## Licensing

Released under a [Creative Commons Attribution-NonCommercial 4.0 International Public License](https://creativecommons.org/licenses/by-nc/4.0/).
